@@ -63,8 +63,8 @@ def send_notifications(email, sender, email_configuration):
     ATTACHMENT = getattr(settings, "LOG_PATH", None)
 
     # The HTML body of the email.
-    file_name = 'Email_Template.html'
-    BODY_HTML = open('media/HTML_files/' + file_name).read().format(
+    file_name = email_configuration.get('HTML_File')
+    BODY_HTML = open('media/' + file_name).read().format(
         paragraph=email_configuration.get('Email_Content'),
         signature=email_configuration.get('Signature'),
         email_us=email_configuration.get('Email_Us'),
@@ -110,7 +110,7 @@ def send_notifications_with_msg(email, sender, msg, email_configuration):
     SUBJECT = email_configuration.get('Subject')
 
     # # The HTML body of the email.
-    file_name = 'Email_Template.html'
+    file_name = email_configuration.get('HTML_File')
     BODY_HTML = open('media/' + file_name).read().format(
         paragraph=msg,
         signature=email_configuration.get('Signature'),
