@@ -49,14 +49,11 @@ class EmailConfiguration(TimeStampedModel):
         ('attachment', 'ATTACHMENT'),
         ('msg', 'MESSAGE'),
     )
-    HTML_File = models.FileField(upload_to='HTML_Files',
-                                 help_text='Check sample HTML files in the '
-                                           'readme files of the components')
 
     Subject = models.CharField(max_length=200,
                                default='OpenLXP Conformance Alerts')
 
-    Email_Content = models.TextField(max_length=200, null=True)
+    Email_Content = models.TextField(max_length=200, null=True, blank=True)
 
     Signature = models.TextField(max_length=200)
 
@@ -72,6 +69,10 @@ class EmailConfiguration(TimeStampedModel):
                                            'components before choosing the '
                                            ' log type')
 
+    HTML_File = models.FileField(upload_to='HTML_Files',
+                                 help_text='Check sample HTML files in the '
+                                           'readme files of the components')
+
     def get_absolute_url(self):
         """ URL for displaying individual model records."""
         return reverse('Configuration-detail', args=[str(self.id)])
